from setuptools import setup

setup(name='gauss_binom_dist_test_by_steve',
      version='0.1',
      description='Gaussian distributions',
      packages=['gauss_binom_dist_test_by_steve'],
      zip_safe=False)
